@@ -12,24 +12,12 @@
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
-*   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
+*   along with this program.  If not, see <https://www.gnu.org/licenses/>. *
 ***************************************************************************/
 
 #ifndef ONMAINWINDOW_H
 #define ONMAINWINDOW_H
 
-#ifdef CFGPLUGIN
-#include <QMetaClassInfo>
-#include <qtbrowserplugin.h>
-
-#ifdef QAXSERVER
-#include <ActiveQt/QAxBindable>
-#include <ActiveQt/QAxFactory>
-#include <qt_windows.h>
-#endif
-
-#endif
-
 #include "x2goclientconfig.h"
 //#include "CallbackInterface.h"
 #include <QMainWindow>
@@ -65,9 +53,6 @@
 @author Oleksandr Shneyder
 */
 
-#if defined(CFGPLUGIN) && defined(Q_OS_LINUX)
-class QX11EmbedContainer;
-#endif
 class QToolButton;
 class QTemporaryFile;
 class QLineEdit;
@@ -266,27 +251,9 @@ Q_SIGNALS:
 
 class ClickLineEdit;
 class ONMainWindow : public QMainWindow
-#ifdef CFGPLUGIN
-    , public QtNPBindable
-
-#ifdef QAXSERVER
-    , public QAxBindable
-#endif
-#endif
 {
     friend class HttpBrokerClient;
     friend class SessionButton;
-#ifdef CFGPLUGIN
-    Q_PROPERTY ( QString x2goconfig READ x2goconfig WRITE setX2goconfig )
-    Q_CLASSINFO ( "ClassID", "{5a20006d-118f-4185-9653-9f98958a0008}" )
-    Q_CLASSINFO ( "InterfaceID", "{2df000ba-da4f-4fb7-8f35-b8dfbf80009a}" )
-    Q_CLASSINFO ( "EventsID", "{44900013-f8bd-4d2e-a2cf-eab407c03005}" )
-    Q_CLASSINFO ( "MIME",
-                  "application/x2go:x2go:Configuration File "
-                  "for X2Go Sessions" )
-    Q_CLASSINFO ( "ToSuperClass", "ONMainWindow" )
-    Q_CLASSINFO ( "DefaultProperty","x2goconfig" )
-#endif
     Q_OBJECT
 public:
     enum
@@ -559,6 +526,7 @@ public:
 
 
     SshMasterConnection* findServerSshConnection(QString host);
+    void cleanServerSshConnections();
 
     void showHelp();
     void showVersion();
@@ -586,7 +554,7 @@ public:
     QSize getEmbedAreaSize();
 #ifdef Q_OS_WIN
     static QString cygwinPath ( const QString& winPath );
-    void startXOrg();
+    void startXOrg(std::size_t start_offset = 0);
     static bool haveCygwinEntry();
     static void removeCygwinEntry();
     static QString U3DevicePath()
@@ -790,7 +758,6 @@ private:
     QProcess* ssh;
     QProcess* soundServer;
     QProcess* scDaemon;
-    QProcess* gpgAgent;
     QProcess* gpg;
     LDAPSession* ld;
     long embedParent;
@@ -803,7 +770,6 @@ private:
     bool newSession;
     bool runStartApp;
     bool ldapOnly;
-    bool isScDaemonOk;
 #ifdef Q_OS_LINUX
     bool directRDP;
 #endif
@@ -891,8 +857,6 @@ private:
     bool shadowSession;
     int firstUid;
     int lastUid;
-    QStringList sshEnv;
-    QString agentPid;
     bool cardReady;
     HttpBrokerClient* broker;
 
@@ -912,6 +876,8 @@ private:
     QString xorgWidth;
     QString xorgHeight;
     int waitingForX;
+    std::size_t x_start_tries_;
+    std::size_t x_start_limit_;
     QRect dispGeometry;
 #endif
 
@@ -968,8 +934,8 @@ private:
     void setUsersEnabled ( bool enable );
     void externalLogout ( const QString& logoutDir );
     void externalLogin ( const QString& loginDir );
-    void startGPGAgent ( const QString& login,
-                         const QString& appId );
+    void startGPG();
+    void GPGCardLogin ( const QString& cardLogin);
     void closeClient();
     void continueNormalSession();
     void continueLDAPSession();
@@ -1152,10 +1118,6 @@ private slots:
                                 QProcess::ExitStatus exitStatus );
     void slotScDaemonError (QProcess::ProcessError error);
     void slotGpgError();
-    void slotCheckScDaemon();
-    void slotGpgAgentFinished ( int exitCode,
-                                QProcess::ExitStatus exitStatus );
-    void slotCheckAgentProcess();
     void slotExecXmodmap();
     void slotCreateSessionIcon();
     void slotFindProxyWin();
@@ -1235,50 +1197,6 @@ private:
     std::size_t default_size_for_key_type (key_types key_type);
     QString generateKey (key_types key_type, bool host_key = false);
     QString createKeyBundle (key_types key_type = RSA_KEY_TYPE);
-
-////////////////plugin stuff////////////////////
-#ifdef CFGPLUGIN
-public slots:
-    void setX2goconfig ( const QString& text );
-public:
-    QString x2goconfig() const
-    {
-        return m_x2goconfig;
-    }
-
-#ifndef Q_OS_DARWIN
-public:
-    void embedWindow ( long wndId );
-    void detachClient();
-private:
-    long parentId;
-    long childId;
-    QSize oldParentSize;
-
-#ifdef Q_OS_LINUX
-    QX11EmbedContainer* embedContainer;
-#endif
-#ifdef Q_OS_WIN
-    QWidget* embedContainer;
-    QPoint oldParentPos;
-    QPoint oldChildPos;
-    QSize oldContainerSize;
-    QTimer *updateTimer;
-    int gcor;
-    long winFlags;
-#endif
-private:
-    QSize getWindowSize ( long winId );
-    void doPluginInit();
-
-#ifdef Q_OS_WIN
-private slots:
-    void slotUpdateEmbedWindow();
-#endif
-
-#endif //(Q_OS_DARWIN)
-#endif
-////////////////end of plugin stuff////////////////////
 };
 
 #ifdef Q_OS_WIN
