@@ -12,7 +12,7 @@
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
-*   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
+*   along with this program.  If not, see <https://www.gnu.org/licenses/>. *
 ***************************************************************************/
 
 #ifndef ONMAINWINDOWPRIVAT_H
@@ -160,12 +160,5 @@
 #include <X11/Xutil.h>
 #endif
 
-#ifdef CFGPLUGIN
-#ifdef Q_OS_LINUX
-#include <dlfcn.h>
-#include <QX11EmbedContainer>
-#endif
-#endif
-
 
 #endif //ONMAINWINDOWPRIVAT_H
