@@ -12,7 +12,7 @@
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
-*   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
+*   along with this program.  If not, see <https://www.gnu.org/licenses/>. *
 ***************************************************************************/
 
 #include "sessionbutton.h"
@@ -376,6 +376,7 @@ void SessionButton::redraw()
     cmdBox->addItem ( "KDE" );
     cmdBox->addItem ( "GNOME" );
     cmdBox->addItem ( "LXDE" );
+    cmdBox->addItem ("LXQt");
     cmdBox->addItem ( "XFCE" );
     cmdBox->addItem ( "MATE" );
     cmdBox->addItem ( "UNITY" );
@@ -422,6 +423,11 @@ void SessionButton::redraw()
         cmdpix.load ( par->iconsPath ( "/16x16/lxde.png" ) );
         cmdBox->setCurrentIndex ( LXDE );
     }
+    else if (command == "LXQt")
+    {
+        cmdpix.load (par->iconsPath ("/16x16/lxqt.png"));
+        cmdBox->setCurrentIndex (LXQt);
+    }
     else if ( command == "CINNAMON" )
     {
         cmdpix.load ( par->iconsPath ( "/16x16/cinnamon.png" ) );
@@ -791,6 +797,11 @@ void SessionButton::slot_cmd_change ( const QString& command )
         newRootless=false;
         pix.load ( par->iconsPath ( "/16x16/lxde.png" ) );
     }
+    else if (command == "LXQt")
+    {
+        newRootless = false;
+        pix.load (par->iconsPath ("/16x16/lxqt.png"));
+    }
     else if ( command =="UNITY" )
     {
         newRootless=false;
@@ -866,6 +877,11 @@ void SessionButton::slot_cmd_change ( const QString& command )
         cmd="LXDE";
         newRootless=false;
     }
+    if (command == "LXQt")
+    {
+        cmd = "LXQt";
+        newRootless = false;
+    }
     if ( command=="unity" )
     {
         cmd="UNITY";
