@@ -12,7 +12,7 @@
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
-*   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
+*   along with this program.  If not, see <https://www.gnu.org/licenses/>. *
 ***************************************************************************/
 
 #ifndef SESSIONBUTTON_H
@@ -32,7 +32,7 @@ class SessionButton : public SVGFrame
 {
     Q_OBJECT
 public:
-    enum {KDE,GNOME,LXDE,XFCE,MATE,UNITY,CINNAMON,TRINITY,OPENBOX,ICEWM,RDP,XDMCP,SHADOW,PUBLISHED,OTHER,APPLICATION};
+    enum {KDE,GNOME,LXDE, LXQt, XFCE,MATE,UNITY,CINNAMON,TRINITY,OPENBOX,ICEWM,RDP,XDMCP,SHADOW,PUBLISHED,OTHER,APPLICATION};
     SessionButton ( ONMainWindow* mw, QWidget* parent,QString id );
     ~SessionButton();
     QString id() {
