@@ -12,7 +12,7 @@
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
-*   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
+*   along with this program.  If not, see <https://www.gnu.org/licenses/>. *
 ***************************************************************************/
 
 #include "sessionwidget.h"
@@ -214,6 +214,7 @@ SessionWidget::SessionWidget ( bool newSession, QString id, ONMainWindow * mw,
     sessBox->addItem ( "KDE" );
     sessBox->addItem ( "GNOME" );
     sessBox->addItem ( "LXDE" );
+    sessBox->addItem ("LXQt");
     sessBox->addItem ( "XFCE" );
     sessBox->addItem ( "MATE" );
     sessBox->addItem ( "UNITY" );
@@ -743,6 +744,11 @@ void SessionWidget::readConfig()
             sessBox->setCurrentIndex ( LXDE );
             cmd->setEnabled ( false );
         }
+        else if (command == "LXQt")
+        {
+            sessBox->setCurrentIndex (LXQt);
+            cmd->setEnabled (false);
+        }
         else if ( command=="UNITY" )
         {
             sessBox->setCurrentIndex ( UNITY );
